@@ -16,16 +16,16 @@
 
 #include "dlglanguage.h"
 
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
-
-#include <KLocalizedString>
-#include <KIconLoader>
-#include <KConfigGroup>
+#include <QDBusInterface>
+#include <QDBusReply>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 
+#include <KConfigGroup>
+#include <KIconLoader>
+#include <KLocalizedString>
+
 #include "kwqtablemodel.h"
 #include "prefs.h"
 
